@@ -27,7 +27,6 @@
 /*
  *  Header files we use
  */
-#define NEED_DBIXS_VERSION 9
 #include <DBIXS.h>  /* installed by the DBI module                        */
 #include "myMsql.h"
 
@@ -152,6 +151,9 @@ struct imp_sth_st {
     int   insertid;       /* ID of auto insert                      */
     imp_sth_ph_t* params; /* Pointer to parameter array             */
     AV* av_attr[AV_ATTRIB_LAST];/*  For caching array attributes        */
+    int   use_mysql_use_result;  /*  TRUE if execute should use     */
+                          /* mysql_use_result rather than           */
+                          /* mysql_store_result */
 };
 
 
@@ -160,7 +162,7 @@ struct imp_sth_st {
  *
  * These defines avoid name clashes for multiple statically linked DBD's	*/
 #ifdef DBD_MYSQL
-#define dbd_init		mysql_init
+#define dbd_init		mysql_dr_init
 #define dbd_db_login		mysql_db_login
 #define dbd_db_do		mysql_db_do
 #define dbd_db_commit		mysql_db_commit
@@ -183,7 +185,7 @@ struct imp_sth_st {
 #define dbd_st_internal_execute mysql_st_internal_execute
 #define mymsql_constant         mysql_constant
 #else
-#define dbd_init		msql_init
+#define dbd_init		msql_dr_init
 #define dbd_db_login		msql_db_login
 #define dbd_db_do		msql_db_do
 #define dbd_db_commit		msql_db_commit
@@ -213,5 +215,5 @@ SV	*dbd_db_fieldlist _((result_t res));
 
 void    dbd_preparse _((imp_sth_t *imp_sth, SV *statement));
 int dbd_st_internal_execute(SV*, SV*, SV*, int, imp_sth_ph_t*, result_t*,
-			    dbh_t);
+			    dbh_t, int);
 
