@@ -83,11 +83,12 @@ typedef m_field* field_t;
 #define IS_PRI_KEY(n) ((n) & 4)
 #endif
 
-int MyConnect(dbh_t*, char*, char*, char*);
+int MyConnect(dbh_t*, char*, char*, char*, char*);
 
 #else
 
 #include <mysql.h>  /* installed during the installation of mysql itself  */
+
 typedef MYSQL* dbh_t;
 typedef MYSQL_RES* result_t;
 typedef MYSQL_ROW row_t;
@@ -115,7 +116,7 @@ typedef MYSQL_FIELD* field_t;
 #define MyFieldSeek(r, i) mysql_field_seek(r, i)
 #define MyDataSeek(r, i) mysql_data_seek(r, i)
 
-int MyConnect(dbh_t, char*, char*, char*);
+int MyConnect(dbh_t, char*, char*, char*, char*);
 
 #if !defined(IS_UNIQUE_KEY)
 #define IS_UNIQUE_KEY(n) ((n) & (UNIQUE_KEY_FLAG | PRI_KEY_FLAG))
